@@ -14,6 +14,7 @@
 package main
 
 import (
+	"context"
 	"encoding/binary"
 	"fmt"
 	"net"
@@ -82,13 +83,13 @@ func listToOid(l []int) string {
 	return strings.Join(result, ".")
 }
 
-func ScrapeTarget(target string, config *config.Module, logger log.Logger) ([]gosnmp.SnmpPDU, error) {
+func ScrapeTarget(ctx context.Context, target string, config *config.Module, logger log.Logger) ([]gosnmp.SnmpPDU, error) {
 	// Set the options.
 	snmp := gosnmp.GoSNMP{}
+	snmp.Context = ctx
 	snmp.MaxRepetitions = config.WalkParams.MaxRepetitions
-	// User specifies timeout of each retry attempt but GoSNMP expects total timeout for all attempts.
 	snmp.Retries = config.WalkParams.Retries
-	snmp.Timeout = config.WalkParams.Timeout * time.Duration(snmp.Retries)
+	snmp.Timeout = config.WalkParams.Timeout
 
 	snmp.Target = target
 	snmp.Port = 161
@@ -107,6 +108,9 @@ func ScrapeTarget(target string, config *config.Module, logger log.Logger) ([]go
 	// Do the actual walk.
 	err := snmp.Connect()
 	if err != nil {
+		if err == context.Canceled {
+			return nil, fmt.Errorf("scrape canceled (possible timeout) connecting to target %s", snmp.Target)
+		}
 		return nil, fmt.Errorf("error connecting to target %s: %s", target, err)
 	}
 	defer snmp.Conn.Close()
@@ -128,6 +132,9 @@ func ScrapeTarget(target string, config *config.Module, logger log.Logger) ([]go
 		getStart := time.Now()
 		packet, err := snmp.Get(getOids[:oids])
 		if err != nil {
+			if err == context.Canceled {
+				return nil, fmt.Errorf("scrape canceled (possible timeout) getting target %s", snmp.Target)
+			}
 			return nil, fmt.Errorf("error getting target %s: %s", snmp.Target, err)
 		}
 		level.Debug(logger).Log("msg", "Get of OIDs completed", "oids", oids, "duration_seconds", time.Since(getStart))
@@ -162,6 +169,9 @@ func ScrapeTarget(target string, config *config.Module, logger log.Logger) ([]go
 			pdus, err = snmp.BulkWalkAll(subtree)
 		}
 		if err != nil {
+			if err == context.Canceled {
+				return nil, fmt.Errorf("scrape canceled (possible timeout) walking target %s", snmp.Target)
+			}
 			return nil, fmt.Errorf("error walking target %s: %s", snmp.Target, err)
 		}
 		level.Debug(logger).Log("msg", "Walk of subtree completed", "oid", subtree, "duration_seconds", time.Since(walkStart))
@@ -195,6 +205,7 @@ func buildMetricTree(metrics []*config.Metric) *MetricNode {
 }
 
 type collector struct {
+	ctx    context.Context
 	target string
 	module *config.Module
 	logger log.Logger
@@ -208,7 +219,7 @@ func (c collector) Describe(ch chan<- *prometheus.Desc) {
 // Collect implements Prometheus.Collector.
 func (c collector) Collect(ch chan<- prometheus.Metric) {
 	start := time.Now()
-	pdus, err := ScrapeTarget(c.target, c.module, c.logger)
+	pdus, err := ScrapeTarget(c.ctx, c.target, c.module, c.logger)
 	if err != nil {
 		level.Info(c.logger).Log("msg", "Error scraping target", "err", err)
 		ch <- prometheus.NewInvalidMetric(prometheus.NewDesc("snmp_error", "Error scraping target", nil, nil), err)
@@ -691,6 +702,9 @@ func indexesToLabels(indexOids []int, metric *config.Metric, oidToPdu map[string
 		}
 		if pdu, ok := oidToPdu[oid]; ok {
 			labels[lookup.Labelname] = pduValueAsString(&pdu, lookup.Type)
+			if _, ok := pdu.Value.(int); ok {
+				labelOids[lookup.Labelname] = []int{pdu.Value.(int)}
+			}
 		} else {
 			labels[lookup.Labelname] = ""
 		}
