@@ -956,6 +956,22 @@ func TestIndexesToLabels(t *testing.T) {
 			oidToPdu: map[string]gosnmp.SnmpPDU{},
 			result:   map[string]string{"l": "0x03C0A8010205"},
 		},
+		{
+			oid: []int{1, 1, 1, 1},
+			metric: config.Metric{
+				Indexes: []*config.Index{{Labelname: "a", Type: "gauge"}},
+				Lookups: []*config.Lookup{
+					{Labels: []string{"a"}, Labelname: "chainable_id", Oid: "1.1.1.2"},
+					{Labels: []string{"chainable_id"}, Labelname: "targetlabel", Oid: "2.2.2"},
+				},
+			},
+			oidToPdu: map[string]gosnmp.SnmpPDU{
+				"1.1.1.1.1": gosnmp.SnmpPDU{Value: "source_obj0"},
+				"1.1.1.2.1": gosnmp.SnmpPDU{Value: 42},
+				"2.2.2.42":  gosnmp.SnmpPDU{Value: "targetvalue"},
+			},
+			result: map[string]string{"a": "1", "chainable_id": "42", "targetlabel": "targetvalue"},
+		},
 	}
 	for _, c := range cases {
 		got := indexesToLabels(c.oid, &c.metric, c.oidToPdu)
